@@ -106,14 +106,10 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     :raises pyilt2.queryError: if the database returns an Error on a query
     """
 
-    print("tem que ser")
-
     proplistUrl = 'https://ilthermo.boulder.nist.gov/ILT2/ilprpls'
 
-    r = requests.get(proplistUrl)
-    prpDict = r.json()
-
-    print(prpDict)
+    r1 = requests.get(proplistUrl)
+    prpDict = r1.json()
 
     prpNames = []
     prpKeys = []
@@ -123,8 +119,6 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
         pcls['name'] = map(str.strip, pcls['name'])
         prpNames += pcls['name']
         prpKeys += pcls['key']
-    
-    print("pogo pogo")
 
     prop2key = dict(zip(prpNames, prpKeys))
 
@@ -144,14 +138,11 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
         keyw = keywords,
         prp = prp
     )
-
+    print(params)
     r = requests.get(searchUrl, params=params)
     resDict = r.json()
     if len(resDict['errors']) > 0:
         e = " *** ".join(resDict['errors'])
-        #JOAO
-        print("len(resDict['errors']) > 0")
-        #JOAO
         raise queryError(e)
     return result(resDict), prop2key
 
